@@ -20,7 +20,7 @@
  * permission are above and beyond the permissions granted by the GPL license
  * Totem is covered by.
  *
- * Monday 7th February 2005: Christian Schaller: Add excemption clause.
+ * Monday 7th February 2005: Christian Schaller: Add exception clause.
  * See license_change file for details.
  *
  */
@@ -33,8 +33,6 @@
 #include <gtk/gtk.h>
 #include <libgnomevfs/gnome-vfs.h>
 
-#include "totem-remote.h"
-#include "totem-scrsaver.h"
 #include "totem-playlist.h"
 #include "bacon-message-connection.h"
 #include "bacon-video-widget.h"
@@ -70,7 +68,9 @@ typedef enum {
 	STATE_STOPPED
 } TotemStates;
 
-struct Totem {
+struct TotemObject {
+	GObject parent;
+
 	/* Control window */
 	GladeXML *xml;
 	GtkWidget *win;
@@ -92,20 +92,23 @@ struct Totem {
 	GtkActionGroup *subtitles_action_group;
 	guint subtitles_ui_id;
 
+	/* Plugins */
+	GtkWidget *plugins;
+
 	/* Sidebar */
 	GtkWidget *sidebar;
 	gboolean sidebar_shown;
 	int sidebar_w;
-
-	/* Separate Dialogs */
 	GtkWidget *properties;
+
+	/* Skip to dialogue */
 	TotemSkipto *skipto;
+	gint64 last_length;
 
 	/* Play/Pause */
 	GtkWidget *pp_button;
 	/* fullscreen Play/Pause */
 	GtkWidget *fs_pp_button;
-	GtkTooltips *tooltip;
 
 	/* Seek */
 	GtkWidget *seek;
@@ -145,8 +148,6 @@ struct Totem {
 	gboolean popup_in_progress;
 	GdkRectangle fullscreen_rect;
 
-	TotemScrsaver *scr;
-
 	/* recent file stuff */
 	GtkRecentManager *recent_manager;
 	GtkActionGroup *recent_action_group;
@@ -170,7 +171,6 @@ struct Totem {
 	char *mrl;
 	TotemPlaylist *playlist;
 	GConfClient *gc;
-	TotemRemote *remote;
 	BaconMessageConnection *conn;
 	TotemStates state;
 	gboolean cursor_shown;
@@ -199,8 +199,4 @@ void	totem_action_show_properties		(Totem *totem);
 
 void	show_controls				(Totem *totem, gboolean was_fullscreen);
 
-gboolean totem_is_fullscreen			(Totem *totem);
-
-
-
 #endif /* __TOTEM_PRIVATE_H__ */
